import{p as D,g,k as M,x as P,aa as S,y as t,z as n,A as o,a9 as I,q as X,a2 as b,n as u,K as d,B as V,G as p,M as A,D as h,J as r,aD as Y,S as C,ak as N,X as O,H as T}from"./index-CFvoaD7J.js";import{M as z}from"./ItemContextMenu.vue_vue_type_style_index_0_scoped_4409cede_lang-41DbVClm.js";import{V as H}from"./VCard-DxLPF-Ra.js";import{m as L,a as _,e as $}from"./VMenu-9pSrU4Fo.js";import{V as E}from"./VCheckbox-B5r7QKHZ.js";import{D as F,E as w,k as q,v as G}from"./VListItem-CSPID7yq.js";import{_ as J}from"./_plugin-vue_export-helper-DlAUqK2U.js";const K=D({disabled:Boolean,modelValue:{type:Boolean,default:null},...L()},"VHover"),R=g()({name:"VHover",props:K(),emits:{"update:modelValue":l=>!0},setup(l,f){let{slots:a}=f;const s=M(l,"modelValue"),{runOpenDelay:m,runCloseDelay:y}=_(l,i=>!l.disabled&&(s.value=i));return()=>{var i;return(i=a.default)==null?void 0:i.call(a,{isHovering:s.value,props:{onMouseenter:m,onMouseleave:y}})}}}),j=["model-value"],Q={key:0},U={key:1},W={key:2},Z=P({__name:"PanelviewItemCompact",props:{item:{},size:{default:200},isSelected:{type:Boolean,default:!1},showCheckboxes:{type:Boolean,default:!1},permanentOverlay:{type:Boolean,default:!1},isAvailable:{type:Boolean,default:!0}},emits:["menu","click","play","select"],setup(l,{emit:f}){const a=l,s=f,m=function(e){if(a.showCheckboxes)return;const k="clientX"in e?e.clientX:e.touches[0].clientX,v="clientY"in e?e.clientY:e.touches[0].clientY;s("menu",a.item,k,v)},y=function(e){if(a.showCheckboxes){s("select",a.item,!a.isSelected);return}s("click",a.item,e.clientX,e.clientY)},i=function(e){a.showCheckboxes||s("play",a.item,e.clientX,e.clientY)};return(e,k)=>{const v=S("hold");return t(),n(R,null,{default:o(({isHovering:c,props:B})=>[I((t(),n(H,X(B,{class:{"on-hover":c,unavailable:!e.isAvailable},elevation:c?3:0,onClick:y,onContextmenu:b(m,["right","prevent"])}),{default:o(()=>[e.showCheckboxes?(t(),n($,{key:0,"model-value":e.showCheckboxes,contained:"",scrim:e.isSelected?e.$vuetify.theme.current.dark?"rgba(0,0,0,.75)":"rgba(255,255,255,.75)":"#ffffff00"},{default:o(()=>[u(E,{class:"panel-item-checkbox",ripple:!1,"model-value":e.isSelected},null,8,["model-value"])]),_:1},8,["model-value","scrim"])):d("",!0),u(z,{item:e.isAvailable?e.item:void 0},null,8,["item"]),V("div",{class:O(e.$vuetify.theme.current.dark?"paneldetails-dark":"paneldetails"),"model-value":c||e.$vuetify.display.mobile||e.permanentOverlay},[u(q,{variant:"text",slim:"",tile:"",density:"compact",class:"panel-item-details"},{default:o(()=>[u(F,null,{default:o(()=>[e.item.media_type==p(A).FOLDER?(t(),h("span",Q,[V("span",null,r(p(Y)(e.item,e.$t)),1)])):(t(),h("span",U,r(e.item.name),1)),"version"in e.item&&e.item.version?(t(),h("span",W," - "+r(e.item.version),1)):d("",!0)]),_:1}),"artists"in e.item&&e.item.artists?(t(),n(w,{key:0,class:"line-clamp-1"},{default:o(()=>[C(r(p(N)(e.item.artists,1)),1)]),_:1})):"owner"in e.item&&e.item.owner?(t(),n(w,{key:1,class:"line-clamp-1"},{default:o(()=>[C(r(e.item.owner),1)]),_:1})):d("",!0)]),_:1})],10,j),(c||p(T).isTouchscreen)&&e.isAvailable?(t(),n(G,{key:1,icon:"mdi-play",color:"primary",fab:"",size:"small",style:{position:"absolute",right:"10px",bottom:"35px",opacity:"0.8"},onClick:b(i,["stop"])})):d("",!0)]),_:2},1040,["class","elevation"])),[[v,m]])]),_:1})}}}),ie=J(Z,[["__scopeId","data-v-c0cf806c"]]);export{ie as P,R as V};
