import{g as p,u as S,e as u,f as h}from"./VMenu-9pSrU4Fo.js";import{p as O,a5 as x,g as T,k,aI as I,c as e,r as w,q as d,n as A}from"./index-CFvoaD7J.js";import{i as C}from"./VListItem-CSPID7yq.js";const R=O({id:String,text:String,...x(p({closeOnBack:!1,location:"end",locationStrategy:"connected",eager:!0,minWidth:0,offset:10,openOnClick:!1,openOnHover:!0,origin:"auto",scrim:!1,scrollStrategy:"reposition",transition:!1}),["absolute","persistent"])},"VTooltip"),F=T()({name:"VTooltip",props:R(),emits:{"update:modelValue":t=>!0},setup(t,v){let{slots:o}=v;const n=k(t,"modelValue"),{scopeId:g}=S(),m=I(),r=e(()=>t.id||`v-tooltip-${m}`),l=w(),f=e(()=>t.location.split(" ").length>1?t.location:t.location+" center"),V=e(()=>t.origin==="auto"||t.origin==="overlap"||t.origin.split(" ").length>1||t.location.split(" ").length>1?t.origin:t.origin+" center"),P=e(()=>t.transition?t.transition:n.value?"scale-transition":"fade-transition"),y=e(()=>d({"aria-describedby":r.value},t.activatorProps));return C(()=>{const b=u.filterProps(t);return A(u,d({ref:l,class:["v-tooltip",t.class],style:t.style,id:r.value},b,{modelValue:n.value,"onUpdate:modelValue":a=>n.value=a,transition:P.value,absolute:!0,location:f.value,origin:V.value,persistent:!0,role:"tooltip",activatorProps:y.value,_disableGlobalStack:!0},g),{activator:o.activator,default:function(){var c;for(var a=arguments.length,s=new Array(a),i=0;i<a;i++)s[i]=arguments[i];return((c=o.default)==null?void 0:c.call(o,...s))??t.text}})}),h({},l)}});export{F as V};
