import{x as p,c as m,I as n,y as a,D as s,z as o,G as r,Y as l}from"./index-CFvoaD7J.js";import{w as d}from"./VListItem-CSPID7yq.js";const u=["title","innerHTML"],c=["title","innerHTML"],z=p({__name:"ProviderIcon",props:{domain:{},size:{},dark:{type:Boolean}},setup(v){const t=v,i=m(()=>{if(t.domain in n.providers)return n.providers[t.domain].domain;if(t.domain in n.providerManifests)return t.domain});return(e,f)=>(a(),s("div",{style:l(`width:${e.size}px;margin-left:10px;margin-right:10px;content-align:center`)},[e.domain&&e.domain=="library"?(a(),o(d,{key:0,size:e.size,icon:"mdi-bookshelf",title:e.$t("item_in_library")},null,8,["size","title"])):e.$vuetify.theme.current.dark&&i.value&&r(n).providerManifests[i.value].icon_svg_dark?(a(),s("div",{key:1,style:l(`width: ${e.size}px;align-content: center;`),title:r(n).providerManifests[i.value].name,innerHTML:r(n).providerManifests[i.value].icon_svg_dark},null,12,u)):i.value&&r(n).providerManifests[i.value].icon_svg?(a(),s("div",{key:2,style:l(`width: ${e.size}px;height: ${e.size}px;align-content: center;`),title:r(n).providerManifests[i.value].name,innerHTML:r(n).providerManifests[i.value].icon_svg},null,12,c)):i.value&&r(n).providerManifests[i.value].icon?(a(),o(d,{key:3,size:e.size,icon:"mdi-"+r(n).providerManifests[i.value].icon,title:r(n).providerManifests[i.value].name,dark:e.$vuetify.theme.current.dark},null,8,["size","icon","title","dark"])):(a(),o(d,{key:4,size:e.size,dark:e.$vuetify.theme.current.dark,icon:"mdi-playlist-play"},null,8,["size","dark"]))],4))}});export{z as _};
