import{x as u,az as l,c as p,N as c,y as a,D as m,n as i,B as d,A as v,z as g,O as f}from"./index-CFvoaD7J.js";import{T as y}from"./Toolbar-DNen7a-V.js";import{V as h}from"./VList-fGk9SRdf.js";import"./VToolbar-Da4d1W_R.js";import"./VListItem-CSPID7yq.js";import"./VMenu-9pSrU4Fo.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";const S=u({__name:"Settings",setup(b){const o=l(),n=p(()=>{var e,t,r;return(e=o.currentRoute.value.name)!=null&&e.toString().includes("player")?"players":(t=o.currentRoute.value.name)!=null&&t.toString().includes("core")?"core":(r=o.currentRoute.value.name)!=null&&r.toString().includes("frontend")?"frontend":"providers"});return(e,t)=>{const r=c("router-view");return a(),m("div",null,[i(y,{icon:"mdi-cog-outline",title:e.$t("settings.settings"),"show-loading":!0,"menu-items":[{label:"settings.providers",icon:"mdi-apps",action:()=>{e.$router.push({name:"providersettings"})},active:n.value=="providers"},{label:"settings.players",icon:"mdi-speaker-multiple",action:()=>{e.$router.push({name:"playersettings"})},active:n.value=="players"},{label:"settings.core",icon:"mdi-engine",action:()=>{e.$router.push({name:"coresettings"})},active:n.value=="core"},{label:"settings.frontend",icon:"mdi-palette-advanced",action:()=>{e.$router.push({name:"frontendsettings"})},active:n.value=="frontend"}]},null,8,["title","menu-items"]),i(h),t[0]||(t[0]=d("div",{style:{height:"15px"}},null,-1)),i(r,{app:""},{default:v(({Component:s})=>[(a(),g(f(s)))]),_:1})])}}});export{S as default};
