import{a as s,d as r,i as o,X as n}from"./VListItem-CSPID7yq.js";import{p as c,g as i,n as l}from"./index-CFvoaD7J.js";const d=c({opacity:[Number,String],...s(),...r()},"VCardSubtitle"),y=i()({name:"VCardSubtitle",props:d(),setup(t,a){let{slots:e}=a;return o(()=>l(t.tag,{class:["v-card-subtitle",t.class],style:[{"--v-card-subtitle-opacity":t.opacity},t.style]},e)),{}}}),C=n("v-card-title"),m=c({opacity:[Number,String],...s(),...r()},"VCardText"),V=i()({name:"VCardText",props:m(),setup(t,a){let{slots:e}=a;return o(()=>l(t.tag,{class:["v-card-text",t.class],style:[{"--v-card-text-opacity":t.opacity},t.style]},e)),{}}});export{C as V,y as a,V as b};
