import{m as I,a as A,u as F,V as t,b as l}from"./VCheckboxBtn-CRgZyCzV.js";import{p as B,a5 as U,g as R,k as q,aI as D,c as M,aY as N,n as u,q as r}from"./index-CFvoaD7J.js";import{i as Y}from"./VListItem-CSPID7yq.js";const $=B({...I(),...U(A(),["inline"])},"VCheckbox"),E=R()({name:"VCheckbox",inheritAttrs:!1,props:$(),emits:{"update:modelValue":e=>!0,"update:focused":e=>!0},setup(e,c){let{attrs:d,slots:a}=c;const s=q(e,"modelValue"),{isFocused:n,focus:i,blur:m}=F(e),V=D(),p=M(()=>e.id||`checkbox-${V}`);return Y(()=>{const[b,f]=N(d),k=t.filterProps(e),v=l.filterProps(e);return u(t,r({class:["v-checkbox",e.class]},b,k,{modelValue:s.value,"onUpdate:modelValue":o=>s.value=o,id:p.value,focused:n.value,style:e.style}),{...a,default:o=>{let{id:x,messagesId:h,isDisabled:P,isReadonly:C,isValid:y}=o;return u(l,r(v,{id:x.value,"aria-describedby":h.value,disabled:P.value,readonly:C.value},f,{error:y.value===!1,modelValue:s.value,"onUpdate:modelValue":g=>s.value=g,onFocus:i,onBlur:m}),a)}})}),{}}});export{E as V};
