import{c as r,ag as c,y as i,z as u,V as d,E as p,q as f,A as v,W as _}from"./index-CFvoaD7J.js";import{_ as m}from"./_plugin-vue_export-helper-DlAUqK2U.js";import{V as h}from"./VContainer-CzfHAKpA.js";const P={props:{variant:{type:String,default:"default",validator:a=>["default","panel"].includes(a)}},setup(a,n){const t=r(()=>({class:"container-default"})),e=r(()=>({class:c.theme.current.value.dark?"container-default container-panels-dark":"container-default container-panels-light"}));return{btnProps:r(()=>{switch(a.variant){case"default":return t.value;case"panel":return e.value;default:return t.value}})}}};function V(a,n,t,e,o,l){return i(),u(h,f(e.btnProps,{variant:"default",fluid:""}),d({_:2},[p(a.$slots,($,s)=>({name:s,fn:v(()=>[_(a.$slots,s,{},void 0,!0)])}))]),1040)}const C=m(P,[["render",V],["__scopeId","data-v-de1efc7e"]]);export{C};
