import{a as p,i as v}from"./VListItem-CSPID7yq.js";import{f as b,g as F}from"./VCheckboxBtn-CRgZyCzV.js";import{f as V}from"./VMenu-9pSrU4Fo.js";import{p as y,g as h,r as R,n as P}from"./index-CFvoaD7J.js";const g=y({...p(),...b()},"VForm"),w=h()({name:"VForm",props:g(),emits:{"update:modelValue":r=>!0,submit:r=>!0},setup(r,f){let{slots:n,emit:i}=f;const a=F(r),s=R();function l(t){t.preventDefault(),a.reset()}function u(t){const o=t,e=a.validate();o.then=e.then.bind(e),o.catch=e.catch.bind(e),o.finally=e.finally.bind(e),i("submit",o),o.defaultPrevented||e.then(c=>{var m;let{valid:d}=c;d&&((m=s.value)==null||m.submit())}),o.preventDefault()}return v(()=>{var t;return P("form",{ref:s,class:["v-form",r.class],style:r.style,novalidate:!0,onReset:l,onSubmit:u},[(t=n.default)==null?void 0:t.call(n,a)])}),V(a,s)}});export{w as V};
