/* empty css              */import{a as t,l as r,d as i,n as l,i as m}from"./VListItem-CSPID7yq.js";import{p as c,g as u,h as p,n as d}from"./index-CFvoaD7J.js";const f=c({fluid:{type:Boolean,default:!1},...t(),...r(),...i()},"VContainer"),g=u()({name:"VContainer",props:f(),setup(e,s){let{slots:a}=s;const{rtlClasses:n}=p(),{dimensionStyles:o}=l(e);return m(()=>d(e.tag,{class:["v-container",{"v-container--fluid":e.fluid},n.value,e.class],style:[o.value,e.style]},a)),{}}});export{g as V};
